@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
@@ -13,7 +13,7 @@ our $SOURCE = 'CPAN';
 # individual JIRA issue as an object.
 
 use Carp;
-use Readonly;
+use Readonly 2.04;
 use Scalar::Util qw( weaken );
 
 # creating a bunch of read-only accessors
@@ -1123,7 +1123,7 @@ JIRA::REST::Class::Issue - A helper class for L<JIRA::REST::Class|JIRA::REST::Cl
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
