@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
 
 # ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents a comment on a JIRA issue as an object.
 
-use Readonly;
+use Readonly 2.04;
 
 # fields that will be turned into JIRA::REST::Class::User objects
 Readonly my @USERS => qw( author updateAuthor );
@@ -113,7 +113,7 @@ JIRA::REST::Class::Issue::Comment - A helper class for L<JIRA::REST::Class|JIRA:
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 METHODS
 
