@@ -4,12 +4,12 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
 
-use Readonly;
+use Readonly 2.04;
 
 # ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents an individual worklog item for a JIRA issue as an object.
 
@@ -110,7 +110,7 @@ JIRA::REST::Class::Issue::Worklog::Item - A helper class for L<JIRA::REST::Class
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 READ-ONLY ACCESSORS
 
