@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
 
 # ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the sprint of a JIRA issue as an object (if you're using L<Atlassian GreenHopper|https://www.atlassian.com/software/jira/agile>).
 
-use Readonly;
+use Readonly 2.04;
 
 Readonly my @ACCESSORS => qw( id rapidViewId state name startDate endDate
                               completeDate sequence );
@@ -65,7 +65,7 @@ JIRA::REST::Class::Sprint - A helper class for L<JIRA::REST::Class|JIRA::REST::C
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 READ-ONLY ACCESSORS
 
